@@ -32,8 +32,8 @@ from .queries import (
     ENERGY_USE_DATA_GRAPHQL_QUERY
 )
 
-API_BASE_URL = "https://r1.wh8.co"
-APP_VERSION = "13.0.7"
+API_BASE_URL = "https://r2.wh8.co"
+APP_VERSION = "13.0.8"
 USER_AGENT = "okhttp/4.9.2"
 
 MAX_RETRIES = 2
@@ -237,7 +237,7 @@ class AOSmithAPIClient:
         logger.debug(f"Sending query, variables: {variables}, login_required: {login_required}, retrying_after_login: {retrying_after_login}, query: {query_log}")
 
         headers = {
-            "brand": "aosmith",
+            "brand": "icomm",
             "version": APP_VERSION,
             "User-Agent": USER_AGENT
         }
